# The Allen SDK

This repository contains code for processing and analyzing data
in the [Allen Brain Atlas](http://brain-map.org/).

Please visit http://alleninstitute.github.io/AllenSDK for more information.
